
local lazypath = vim.fn.stdpath("data") .. "/lazy/lazy.nvim"
if not vim.loop.fs_stat(lazypath) then
  vim.fn.system({
    "git",
    "clone",
    "--filter=blob:none",
    "https://github.com/folke/lazy.nvim.git",
    "--branch=stable", -- latest stable release
    lazypath,
  })
end
vim.opt.rtp:prepend(lazypath)


-- require("lazy").setup(plugins, opts)





require("lazy").setup({

    "navarasu/onedark.nvim",
    "HiPhish/nvim-ts-rainbow2",

    "folke/twilight.nvim",
    "folke/zen-mode.nvim",
    "MunifTanjim/nui.nvim",

    "kassio/neoterm",

    "bkad/camelcasemotion",
    "ggandor/lightspeed.nvim",

    "tpope/vim-commentary",

    "ThePrimeagen/harpoon",
    "eandrju/cellular-automaton.nvim",
    "dbinagi/nomodoro",

    "EdenEast/nightfox.nvim",


    {

        "shellRaining/hlchunk.nvim",
        event = { "UIEnter" },

    },


    {
        'windwp/nvim-autopairs',
        event = "InsertEnter",
        opts = {} -- this is equalent to setup({}) function
    },



    {
        "nvim-lualine/lualine.nvim",
        dependencies =
        {
            "nvim-tree/nvim-web-devicons",
            opt = true
        }
    },


    {
        "NvChad/nvim-colorizer.lua",
        config = function()
            require('colorizer').setup()
        end,
    },


    {
      "m4xshen/hardtime.nvim",
      lazy = true,
      opts = {}
    },


    {
        "folke/noice.nvim",
        config = function ()
            require("plugins.noice")
        end
    },


    {
        "willothy/veil.nvim",
        dependencies = {
            "nvim-telescope/telescope.nvim",
            "nvim-lua/plenary.nvim",
            "nvim-telescope/telescope-file-browser.nvim"
        },
    },





    -- size does not matter
    {
        'echasnovski/mini.nvim',
        version = false,
    },


    -- File manager who?
    {
        "ms-jpq/chadtree",
        version = 'chad',
        build = 'python3 -m chadtree deps',
    },


    -- need that syntax highlight amirite
    {
        "nvim-treesitter/nvim-treesitter",
        build = ":TSUpdate"
    },


    -- the name says it all
    {
        "SirVer/ultisnips",
        lazy = true
    },

    -- That shmexy latex plugin
    {
        "lervag/vimtex",
        lazy = true
    },

    -- DAMN, org mode?
    {
        "nvim-neorg/neorg",
        lazy = true
    },


    -- Cool screensaver !!
    {
        "folke/drop.nvim",
        event = "VimEnter",
    },


    {
      'VonHeikemen/lsp-zero.nvim',
      branch = 'v2.x',
      dependencies = {
        -- LSP Support
        {'neovim/nvim-lspconfig'},             -- Required
        {'williamboman/mason.nvim'},           -- Optional
        {'williamboman/mason-lspconfig.nvim'}, -- Optional

        -- Autocompletion
        {'hrsh7th/nvim-cmp'},     -- Required
        {'hrsh7th/cmp-nvim-lsp'}, -- Required
        {'L3MON4D3/LuaSnip'},     -- Required
      }
    },

})








vim.opt.laststatus=2

vim.keymap.set('i', '<Tab>',   [[pumvisible() ? "\<C-n>" : "\<Tab>"]],   { expr = true })
vim.keymap.set('i', '<S-Tab>', [[pumvisible() ? "\<C-p>" : "\<S-Tab>"]], { expr = true })


